@@ -170,12 +170,10 @@ static void EnsureDistributedSequencesHaveOneType(Oid relationId,
 static void CopyLocalDataIntoShards(Oid distributedTableId);
 static List * TupleDescColumnNameList(TupleDesc tupleDescriptor);
 
-#if (PG_VERSION_NUM >= PG_VERSION_15)
 static bool DistributionColumnUsesNumericColumnNegativeScale(TupleDesc relationDesc,
 															 Var *distributionColumn);
 static int numeric_typmod_scale(int32 typmod);
 static bool is_valid_numeric_typmod(int32 typmod);
-#endif
 
 static bool DistributionColumnUsesGeneratedStoredColumn(TupleDesc relationDesc,
 														Var *distributionColumn);
@@ -834,7 +832,7 @@ HashSplitPointsForShardList(List *shardList)
 	List *splitPointList = NIL;
 
 	ShardInterval *shardInterval = NULL;
-	foreach_ptr(shardInterval, shardList)
+	foreach_declared_ptr(shardInterval, shardList)
 	{
 		int32 shardMaxValue = DatumGetInt32(shardInterval->maxValue);
 
@@ -890,7 +888,7 @@ WorkerNodesForShardList(List *shardList)
 	List *nodeIdList = NIL;
 
 	ShardInterval *shardInterval = NULL;
-	foreach_ptr(shardInterval, shardList)
+	foreach_declared_ptr(shardInterval, shardList)
 	{
 		WorkerNode *workerNode = ActiveShardPlacementWorkerNode(shardInterval->shardId);
 		nodeIdList = lappend_int(nodeIdList, workerNode->nodeId);
@@ -1325,10 +1323,7 @@ CreateCitusTable(Oid relationId, CitusTableType tableType,
 	{
 		List *partitionList = PartitionList(relationId);
 		Oid partitionRelationId = InvalidOid;
-		Oid namespaceId = get_rel_namespace(relationId);
-		char *schemaName = get_namespace_name(namespaceId);
-		char *relationName = get_rel_name(relationId);
-		char *parentRelationName = quote_qualified_identifier(schemaName, relationName);
+		char *parentRelationName = generate_qualified_relation_name(relationId);
 
 		/*
 		 * when there are many partitions, each call to CreateDistributedTable
@@ -1340,7 +1335,7 @@ CreateCitusTable(Oid relationId, CitusTableType tableType,
 								  ALLOCSET_DEFAULT_SIZES);
 		MemoryContext oldContext = MemoryContextSwitchTo(citusPartitionContext);
 
-		foreach_oid(partitionRelationId, partitionList)
+		foreach_declared_oid(partitionRelationId, partitionList)
 		{
 			MemoryContextReset(citusPartitionContext);
 
@@ -1554,7 +1549,7 @@ ConvertCitusLocalTableToTableType(Oid relationId, CitusTableType tableType,
 		MemoryContext oldContext = MemoryContextSwitchTo(citusPartitionContext);
 
 		Oid partitionRelationId = InvalidOid;
-		foreach_oid(partitionRelationId, partitionList)
+		foreach_declared_oid(partitionRelationId, partitionList)
 		{
 			MemoryContextReset(citusPartitionContext);
 
@@ -1704,7 +1699,7 @@ EnsureSequenceTypeSupported(Oid seqOid, Oid attributeTypeId, Oid ownerRelationId
 	Oid attrDefOid;
 	List *attrDefOids = GetAttrDefsFromSequence(seqOid);
 
-	foreach_oid(attrDefOid, attrDefOids)
+	foreach_declared_oid(attrDefOid, attrDefOids)
 	{
 		ObjectAddress columnAddress = GetAttrDefaultColumnAddress(attrDefOid);
 
@@ -1786,7 +1781,7 @@ static void
 EnsureDistributedSequencesHaveOneType(Oid relationId, List *seqInfoList)
 {
 	SequenceInfo *seqInfo = NULL;
-	foreach_ptr(seqInfo, seqInfoList)
+	foreach_declared_ptr(seqInfo, seqInfoList)
 	{
 		if (!seqInfo->isNextValDefault)
 		{
@@ -2117,8 +2112,6 @@ EnsureRelationCanBeDistributed(Oid relationId, Var *distributionColumn,
 								  "AS (...) STORED.")));
 	}
 
-#if (PG_VERSION_NUM >= PG_VERSION_15)
-
 	/* verify target relation is not distributed by a column of type numeric with negative scale */
 	if (distributionMethod != DISTRIBUTE_BY_NONE &&
 		DistributionColumnUsesNumericColumnNegativeScale(relationDesc,
@@ -2129,7 +2122,6 @@ EnsureRelationCanBeDistributed(Oid relationId, Var *distributionColumn,
 						errdetail("Distribution column must not use numeric type "
 								  "with negative scale")));
 	}
-#endif
 
 	/* check for support function needed by specified partition method */
 	if (distributionMethod == DISTRIBUTE_BY_HASH)
@@ -2847,8 +2839,6 @@ TupleDescColumnNameList(TupleDesc tupleDescriptor)
 }
 
 
-#if (PG_VERSION_NUM >= PG_VERSION_15)
-
 /*
  * is_valid_numeric_typmod checks if the typmod value is valid
  *
@@ -2898,8 +2888,6 @@ DistributionColumnUsesNumericColumnNegativeScale(TupleDesc relationDesc,
 }
 
 
-#endif
-
 /*
  * DistributionColumnUsesGeneratedStoredColumn returns whether a given relation uses
  * GENERATED ALWAYS AS (...) STORED on distribution column
