@@ -614,16 +614,6 @@ WaitForSharedConnection(void)
 void
 InitializeSharedConnectionStats(void)
 {
-/* on PG 15, we use shmem_request_hook_type */
-#if PG_VERSION_NUM < PG_VERSION_15
-
-	/* allocate shared memory */
-	if (!IsUnderPostmaster)
-	{
-		RequestAddinShmemSpace(SharedConnectionStatsShmemSize());
-	}
-#endif
-
 	prev_shmem_startup_hook = shmem_startup_hook;
 	shmem_startup_hook = SharedConnectionStatsShmemInit;
 }
