@@ -207,7 +207,7 @@ GetUniqueDependenciesList(List *objectAddressesList)
 	InitObjectAddressCollector(&objectAddressCollector);
 
 	ObjectAddress *objectAddress = NULL;
-	foreach_ptr(objectAddress, objectAddressesList)
+	foreach_declared_ptr(objectAddress, objectAddressesList)
 	{
 		if (IsObjectAddressCollected(*objectAddress, &objectAddressCollector))
 		{
@@ -334,7 +334,7 @@ OrderObjectAddressListInDependencyOrder(List *objectAddressList)
 	InitObjectAddressCollector(&collector);
 
 	ObjectAddress *objectAddress = NULL;
-	foreach_ptr(objectAddress, objectAddressList)
+	foreach_declared_ptr(objectAddress, objectAddressList)
 	{
 		if (IsObjectAddressCollected(*objectAddress, &collector))
 		{
@@ -403,7 +403,7 @@ RecurseObjectDependencies(ObjectAddress target, expandFn expand, followFn follow
 
 	/* iterate all entries and recurse depth first */
 	DependencyDefinition *dependencyDefinition = NULL;
-	foreach_ptr(dependencyDefinition, dependenyDefinitionList)
+	foreach_declared_ptr(dependencyDefinition, dependenyDefinitionList)
 	{
 		if (follow == NULL || !follow(collector, dependencyDefinition))
 		{
@@ -870,7 +870,7 @@ bool
 ErrorOrWarnIfAnyObjectHasUnsupportedDependency(List *objectAddresses)
 {
 	ObjectAddress *objectAddress = NULL;
-	foreach_ptr(objectAddress, objectAddresses)
+	foreach_declared_ptr(objectAddress, objectAddresses)
 	{
 		if (ErrorOrWarnIfObjectHasUnsupportedDependency(objectAddress))
 		{
@@ -963,7 +963,7 @@ DeferErrorIfAnyObjectHasUnsupportedDependency(const List *objectAddresses)
 {
 	DeferredErrorMessage *deferredErrorMessage = NULL;
 	ObjectAddress *objectAddress = NULL;
-	foreach_ptr(objectAddress, objectAddresses)
+	foreach_declared_ptr(objectAddress, objectAddresses)
 	{
 		deferredErrorMessage = DeferErrorIfHasUnsupportedDependency(objectAddress);
 		if (deferredErrorMessage)
@@ -996,7 +996,7 @@ GetUndistributableDependency(const ObjectAddress *objectAddress)
 		return NULL;
 	}
 
-	foreach_ptr(dependency, dependencies)
+	foreach_declared_ptr(dependency, dependencies)
 	{
 		/*
 		 * Objects with the id smaller than FirstNormalObjectId should be created within
@@ -1173,7 +1173,7 @@ IsAnyObjectAddressOwnedByExtension(const List *targets,
 								   ObjectAddress *extensionAddress)
 {
 	ObjectAddress *target = NULL;
-	foreach_ptr(target, targets)
+	foreach_declared_ptr(target, targets)
 	{
 		if (IsObjectAddressOwnedByExtension(target, extensionAddress))
 		{
@@ -1564,7 +1564,7 @@ ExpandCitusSupportedTypes(ObjectAddressCollector *collector, ObjectAddress targe
 			List *FDWOids = GetDependentFDWsToExtension(extensionId);
 
 			Oid FDWOid = InvalidOid;
-			foreach_oid(FDWOid, FDWOids)
+			foreach_declared_oid(FDWOid, FDWOids)
 			{
 				List *dependentRoleIds = GetDependentRoleIdsFDW(FDWOid);
 				List *dependencies =
@@ -1717,13 +1717,11 @@ ExpandCitusSupportedTypes(ObjectAddressCollector *collector, ObjectAddress targe
 			/*
 			 * As of PostgreSQL 15, the same applies to schemas.
 			 */
-#if PG_VERSION_NUM >= PG_VERSION_15
 			List *schemaIdList =
 				GetPublicationSchemas(publicationId);
 			List *schemaDependencyList =
 				CreateObjectAddressDependencyDefList(NamespaceRelationId, schemaIdList);
 			result = list_concat(result, schemaDependencyList);
-#endif
 
 			break;
 		}
@@ -1850,7 +1848,7 @@ GetViewRuleReferenceDependencyList(Oid viewId)
 	List *nonInternalDependenciesOfDependingRules = NIL;
 
 	HeapTuple depTup = NULL;
-	foreach_ptr(depTup, dependencyTupleList)
+	foreach_declared_ptr(depTup, dependencyTupleList)
 	{
 		Form_pg_depend pg_depend = (Form_pg_depend) GETSTRUCT(depTup);
 
@@ -1873,7 +1871,7 @@ GetViewRuleReferenceDependencyList(Oid viewId)
 			List *ruleDependencies = DependencyDefinitionFromPgDepend(ruleAddress);
 
 			DependencyDefinition *dependencyDef = NULL;
-			foreach_ptr(dependencyDef, ruleDependencies)
+			foreach_declared_ptr(dependencyDef, ruleDependencies)
 			{
 				/*
 				 * Follow all dependencies of the internally dependent rule dependencies
@@ -1908,7 +1906,7 @@ GetRelationSequenceDependencyList(Oid relationId)
 
 	List *seqIdList = NIL;
 	SequenceInfo *seqInfo = NULL;
-	foreach_ptr(seqInfo, seqInfoList)
+	foreach_declared_ptr(seqInfo, seqInfoList)
 	{
 		seqIdList = lappend_oid(seqIdList, seqInfo->sequenceOid);
 	}
@@ -1981,7 +1979,7 @@ GetRelationTriggerFunctionDependencyList(Oid relationId)
 
 	List *triggerIdList = GetExplicitTriggerIdList(relationId);
 	Oid triggerId = InvalidOid;
-	foreach_oid(triggerId, triggerIdList)
+	foreach_declared_oid(triggerId, triggerIdList)
 	{
 		Oid functionId = GetTriggerFunctionId(triggerId);
 		DependencyDefinition *dependency =
@@ -2006,7 +2004,7 @@ GetPublicationRelationsDependencyList(Oid publicationId)
 
 	Oid relationId = InvalidOid;
 
-	foreach_oid(relationId, allRelationIds)
+	foreach_declared_oid(relationId, allRelationIds)
 	{
 		if (!IsCitusTable(relationId))
 		{
@@ -2088,7 +2086,7 @@ CreateObjectAddressDependencyDefList(Oid classId, List *objectIdList)
 {
 	List *dependencyList = NIL;
 	Oid objectId = InvalidOid;
-	foreach_oid(objectId, objectIdList)
+	foreach_declared_oid(objectId, objectIdList)
 	{
 		DependencyDefinition *dependency =
 			CreateObjectAddressDependencyDef(classId, objectId);
@@ -2162,7 +2160,7 @@ BuildViewDependencyGraph(Oid relationId, HTAB *nodeMap)
 																	 targetObjectId);
 
 	HeapTuple depTup = NULL;
-	foreach_ptr(depTup, dependencyTupleList)
+	foreach_declared_ptr(depTup, dependencyTupleList)
 	{
 		Form_pg_depend pg_depend = (Form_pg_depend) GETSTRUCT(depTup);
 
@@ -2241,7 +2239,7 @@ GetDependingViews(Oid relationId)
 	foreach_ptr_append(node, nodeQueue)
 	{
 		ViewDependencyNode *dependingNode = NULL;
-		foreach_ptr(dependingNode, node->dependingNodes)
+		foreach_declared_ptr(dependingNode, node->dependingNodes)
 		{
 			ObjectAddress relationAddress = { 0 };
 			ObjectAddressSet(relationAddress, RelationRelationId, dependingNode->id);
