@@ -217,6 +217,9 @@ citus_set_coordinator_host(PG_FUNCTION_ARGS)
 		EnsureTransactionalMetadataSyncMode();
 	}
 
+	/* prevent concurrent modification */
+	LockRelationOid(DistNodeRelationId(), RowExclusiveLock);
+
 	bool isCoordinatorInMetadata = false;
 	WorkerNode *coordinatorNode = PrimaryNodeForGroup(COORDINATOR_GROUP_ID,
 													  &isCoordinatorInMetadata);
@@ -987,7 +990,7 @@ MarkNodesNotSyncedInLoopBackConnection(MetadataSyncContext *context,
 
 	List *commandList = NIL;
 	WorkerNode *workerNode = NULL;
-	foreach_ptr(workerNode, context->activatedWorkerNodeList)
+	foreach_declared_ptr(workerNode, context->activatedWorkerNodeList)
 	{
 		/*
 		 * We need to prevent self deadlock when we access pg_dist_node using separate
@@ -1020,7 +1023,7 @@ SetNodeMetadata(MetadataSyncContext *context, bool localOnly)
 		List *updatedActivatedNodeList = NIL;
 
 		WorkerNode *node = NULL;
-		foreach_ptr(node, context->activatedWorkerNodeList)
+		foreach_declared_ptr(node, context->activatedWorkerNodeList)
 		{
 			node = SetWorkerColumnLocalOnly(node, Anum_pg_dist_node_isactive,
 											BoolGetDatum(true));
@@ -1039,7 +1042,7 @@ SetNodeMetadata(MetadataSyncContext *context, bool localOnly)
 	if (!localOnly && EnableMetadataSync)
 	{
 		WorkerNode *node = NULL;
-		foreach_ptr(node, context->activatedWorkerNodeList)
+		foreach_declared_ptr(node, context->activatedWorkerNodeList)
 		{
 			SetNodeStateViaMetadataContext(context, node, BoolGetDatum(true));
 		}
@@ -1835,7 +1838,7 @@ FindNodeAnyClusterByNodeId(uint32 nodeId)
 	List *nodeList = ReadDistNode(includeNodesFromOtherClusters);
 	WorkerNode *node = NULL;
 
-	foreach_ptr(node, nodeList)
+	foreach_declared_ptr(node, nodeList)
 	{
 		if (node->nodeId == nodeId)
 		{
@@ -1857,7 +1860,7 @@ FindNodeWithNodeId(int nodeId, bool missingOk)
 	List *nodeList = ActiveReadableNodeList();
 	WorkerNode *node = NULL;
 
-	foreach_ptr(node, nodeList)
+	foreach_declared_ptr(node, nodeList)
 	{
 		if (node->nodeId == nodeId)
 		{
@@ -1885,7 +1888,7 @@ FindCoordinatorNodeId()
 	List *nodeList = ReadDistNode(includeNodesFromOtherClusters);
 	WorkerNode *node = NULL;
 
-	foreach_ptr(node, nodeList)
+	foreach_declared_ptr(node, nodeList)
 	{
 		if (NodeIsCoordinator(node))
 		{
@@ -2015,7 +2018,7 @@ ErrorIfNodeContainsNonRemovablePlacements(WorkerNode *workerNode)
 	shardPlacements = SortList(shardPlacements, CompareGroupShardPlacements);
 
 	GroupShardPlacement *placement = NULL;
-	foreach_ptr(placement, shardPlacements)
+	foreach_declared_ptr(placement, shardPlacements)
 	{
 		if (!PlacementHasActivePlacementOnAnotherGroup(placement))
 		{
@@ -2051,7 +2054,7 @@ PlacementHasActivePlacementOnAnotherGroup(GroupShardPlacement *sourcePlacement)
 
 	bool foundActivePlacementOnAnotherGroup = false;
 	ShardPlacement *activePlacement = NULL;
-	foreach_ptr(activePlacement, activePlacementList)
+	foreach_declared_ptr(activePlacement, activePlacementList)
 	{
 		if (activePlacement->groupId != sourcePlacement->groupId)
 		{
@@ -2402,7 +2405,7 @@ SetWorkerColumnOptional(WorkerNode *workerNode, int columnIndex, Datum value)
 
 	/* open connections in parallel */
 	WorkerNode *worker = NULL;
-	foreach_ptr(worker, workerNodeList)
+	foreach_declared_ptr(worker, workerNodeList)
 	{
 		bool success = SendOptionalMetadataCommandListToWorkerInCoordinatedTransaction(
 			worker->workerName, worker->workerPort,
@@ -2856,9 +2859,7 @@ InsertNodeRow(int nodeid, char *nodeName, int32 nodePort, NodeMetadata *nodeMeta
 	TupleDesc tupleDescriptor = RelationGetDescr(pgDistNode);
 	HeapTuple heapTuple = heap_form_tuple(tupleDescriptor, values, isNulls);
 
-	PushActiveSnapshot(GetTransactionSnapshot());
 	CatalogTupleInsert(pgDistNode, heapTuple);
-	PopActiveSnapshot();
 
 	CitusInvalidateRelcacheByRelid(DistNodeRelationId());
 
@@ -3106,7 +3107,7 @@ static void
 ErrorIfAnyNodeNotExist(List *nodeList)
 {
 	WorkerNode *node = NULL;
-	foreach_ptr(node, nodeList)
+	foreach_declared_ptr(node, nodeList)
 	{
 		/*
 		 * First, locally mark the node is active, if everything goes well,
@@ -3155,7 +3156,7 @@ static void
 SendDeletionCommandsForReplicatedTablePlacements(MetadataSyncContext *context)
 {
 	WorkerNode *node = NULL;
-	foreach_ptr(node, context->activatedWorkerNodeList)
+	foreach_declared_ptr(node, context->activatedWorkerNodeList)
 	{
 		if (!node->isActive)
 		{
