@@ -120,7 +120,10 @@ END;
             count(distinct result) INTO worker_node_version_count
           FROM
             run_command_on_workers('SELECT extversion from pg_extension WHERE extname = ''citus''');
-          IF enforce_version_check AND worker_node_version_count != 1 THEN
+
+          IF enforce_version_check AND worker_node_version_count = 0 THEN
+      RAISE DEBUG 'There are no worker nodes';
+          ELSIF enforce_version_check AND worker_node_version_count != 1 THEN
                     RAISE EXCEPTION 'All nodes should have the same Citus version installed. Currently '
                                      'some of the workers have different versions.';
           ELSE
