@@ -16,6 +16,7 @@ HAVING (
        ) > 0;
 
 -- lets pin the plan in the test as well
+SELECT public.explain_with_pg17_initplan_format($Q$
 EXPLAIN (COSTS OFF)
 SELECT count(*),
        o_orderstatus
@@ -25,3 +26,4 @@ HAVING (
            SELECT count(*)
            FROM customer
        ) > 0;
+$Q$) as "QUERY PLAN";
