@@ -1,13 +1,6 @@
 --
 -- PG15
 --
-SHOW server_version \gset
-SELECT substring(:'server_version', '\d+')::int >= 15 AS server_version_ge_15
-\gset
-\if :server_version_ge_15
-\else
-\q
-\endif
 
 CREATE SCHEMA pg15;
 SET search_path TO pg15;
@@ -41,9 +34,36 @@ SELECT result FROM run_command_on_all_nodes('
 SELECT result FROM run_command_on_all_nodes('
     SELECT collctype FROM pg_collation WHERE collname = ''german_phonebook_test'';
 ');
-SELECT result FROM run_command_on_all_nodes('
-    SELECT colliculocale FROM pg_collation WHERE collname = ''german_phonebook_test'';
-');
+
+-- PG17 renamed colliculocale to colllocale
+-- Relevant PG commit:
+-- https://github.com/postgres/postgres/commit/f696c0cd5f299f1b51e214efc55a22a782cc175d
+
+SHOW server_version \gset
+SELECT substring(:'server_version', '\d+')::int >= 17 AS server_version_ge_17
+\gset
+
+\if :server_version_ge_17
+SELECT '$$' ||
+       'SELECT colllocale FROM pg_collation WHERE collname = ''german_phonebook_test'';'
+       || '$$'
+    AS worker_query_1 \gset
+SELECT '$$' ||
+       'SELECT colllocale FROM pg_collation WHERE collname = ''default_provider'';'
+       || '$$'
+    AS worker_query_2 \gset
+\else
+SELECT '$$' ||
+       'SELECT colliculocale FROM pg_collation WHERE collname = ''german_phonebook_test'';'
+       || '$$'
+    AS worker_query_1 \gset
+SELECT '$$' ||
+       'SELECT colliculocale FROM pg_collation WHERE collname = ''default_provider'';'
+       || '$$'
+    AS worker_query_2 \gset
+\endif
+
+SELECT result FROM run_command_on_all_nodes(:worker_query_1);
 
 -- with non-icu provider, colliculocale will be null, collcollate and collctype will be set
 CREATE COLLATION default_provider (provider = libc, lc_collate = "POSIX", lc_ctype = "POSIX");
@@ -54,9 +74,7 @@ SELECT result FROM run_command_on_all_nodes('
 SELECT result FROM run_command_on_all_nodes('
     SELECT collctype FROM pg_collation WHERE collname = ''default_provider'';
 ');
-SELECT result FROM run_command_on_all_nodes('
-    SELECT colliculocale FROM pg_collation WHERE collname = ''default_provider'';
-');
+SELECT result FROM run_command_on_all_nodes(:worker_query_2);
 
 --
 -- In PG15, Renaming triggers on partitioned tables had two problems
@@ -262,16 +280,6 @@ WITH targq AS (
 MERGE INTO tbl1 USING targq ON (true)
 WHEN MATCHED THEN DELETE;
 
-WITH foo AS (
-  MERGE INTO tbl1 USING tbl2 ON (true)
-  WHEN MATCHED THEN DELETE
-) SELECT * FROM foo;
-
-COPY (
-  MERGE INTO tbl1 USING tbl2 ON (true)
-  WHEN MATCHED THEN DELETE
-) TO stdout;
-
 MERGE INTO tbl1 t
 USING tbl2
 ON (true)
